indexing

	description: "Test POSIX exec process class."

  author: "Berend de Boer"
	date: "$Date: Thu, 12 Oct 2000 20:41:01 +0200 $"
	revision: "$Revision: 1.4 $"

class 

   TEST_P_EXEC_PROCESS

inherit
   
   POSIX_CURRENT_PROCESS


creation
   
   make

   
feature

   make is
      local
         ls,
         more,
         mail: POSIX_EXEC_PROCESS
         signal: POSIX_SIGNAL
         i: INTEGER
      do
         print ("Begin test exec process.%N")         
         print ("My pid: ")
         print (pid)
         print ("%N")

         -- necessary under SmallEiffel
         ignore_child_stop_signal

         -- test input capturing
         print ("Test input capturing.%N")         
         create more.make_capture_input ("more", Void)
         more.execute
         print ("more pid: ")
         print (more.pid)
         print ("%N")
         from
            i := 0
         until 
            i = 25
         loop
            more.stdin.put_string (i.out)
            more.stdin.put_string ("%N")
            i := i + 1
         end

         -- send EOF to more so it will exit
         more.stdin.close

         -- wait for more to terminate
         wait
         
         -- execute ls and pipe output to more
         print ("Test output and input capturing.%N")         
         create ls.make_capture_output ("ls", Void)
         create more.make_capture_input ("more", Void)
         ls.execute
         print ("ls pid: ")
         print (ls.pid)
         print ("%N")
         more.execute
         print ("more pid: ")
         print (more.pid)
         print ("%N")
         from
            ls.stdout.read_string (512)
         until 
            ls.stdout.eof 
         loop
            -- print (ls.stdout.last_string)
            more.stdin.put_string (ls.stdout.last_string)
            ls.stdout.read_string (512)
         end

         -- close captured io for both processes
         ls.stdout.close
         more.stdin.close

         -- wait for both (!) processes
         ls.wait_for (True)
         more.wait_for (True)
         if more.is_terminated_normally then
            print ("Normal exit.%N")
         else
            print ("!! Not normal exit.%N")
         end

         print ("Test exit code.%N")
         ls.set_arguments (<<"QQ*">>)
         ls.execute
         ls.wait_for (True)
         if ls.is_terminated_normally then
            print ("Exit code: ")
            print (ls.exit_code)
            print ("%N")
         else
            print ("!! Not normal exit.%N")
         end

         print ("Test wait_for.%N")
         ls.set_arguments (<<"QQ*">>)
         ls.execute
         ls.wait_for (False)
         if not ls.is_terminated then
            print ("Status not yet available.%N")
            ls.wait_for (True)
         end
         if ls.is_terminated_normally then
            print ("Exit code: ")
            print (ls.exit_code)
            print ("%N")
         else
            print ("!! Not normal exit.%N")
         end

         print ("Test kill on the mail program.%N")

         -- we first have to turn off the (Small)Eiffel signal
         -- handling, this should move to forked process??
         create signal.make (SIGTERM)
         signal.set_default_action
         signal.apply

         create mail.make ("mail", Void)
         mail.set_capture_error (True)
         mail.execute
         mail.wait_for (False)
         if not mail.is_terminated then
            print ("Status not yet available.%N")
            mail.terminate
         end
         mail.wait_for (True)
         if mail.is_terminated_normally then
            print ("!! mail terminated normally. (error or due to Eiffel exception handling? Works sometimes...).%N")
         else
            if mail.is_signaled then
               print ("mail was signalled.%N")
               print ("signal: ")
               print (mail.signal_code)
               print ("%N")
            else
               print ("!! mail was not signalled.%N")
            end
         end

         print ("End test exec process.%N")         
      end
   
end -- class TEST_P_EXEC_PROCESS
